Localisation updates for core messages from translatewiki.net (2009-08-18 23:54 UTC)
[lhc/web/wiklou.git] / api.php
diff --git a/api.php b/api.php
index ce445ef..16657ca 100644 (file)
--- a/api.php
+++ b/api.php
@@ -1,25 +1,27 @@
 <?php
 
/*
* API for MediaWiki 1.8+
*
* Copyright (C) 2006 Yuri Astrakhan <Firstname><Lastname>@gmail.com
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License along
* with this program; if not, write to the Free Software Foundation, Inc.,
* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
* http://www.gnu.org/copyleft/gpl.html
*/
 
 /** 
  * This file is the entry point for all API queries. It begins by checking 
@@ -47,16 +49,10 @@ wfProfileIn('api.php');
 // which will end up triggering HTML detection and execution, hence
 // XSS injection and all that entails.
 //
-// Ensure that all access is through the canonical entry point...
-//
-if( isset( $_SERVER['SCRIPT_URL'] ) ) {
-       $url = $_SERVER['SCRIPT_URL'];
-} else {
-       $url = $_SERVER['PHP_SELF'];
-}
-if( strcmp( "$wgScriptPath/api$wgScriptExtension", $url ) ) {
+if( $wgRequest->isPathInfoBad() ) {
        wfHttpError( 403, 'Forbidden',
-               'API must be accessed through the primary script entry point.' );
+               'Invalid file extension found in PATH_INFO. ' . 
+               'The API must be accessed through the primary script entry point.' );
        return;
 }
 
@@ -64,9 +60,35 @@ if( strcmp( "$wgScriptPath/api$wgScriptExtension", $url ) ) {
 if (!$wgEnableAPI) {
        echo 'MediaWiki API is not enabled for this site. Add the following line to your LocalSettings.php';
        echo '<pre><b>$wgEnableAPI=true;</b></pre>';
-       die(-1);
+       die(1);
+}
+
+// Selectively allow cross-site AJAX
+if ( $wgCrossSiteAJAXdomains && isset($_SERVER['HTTP_ORIGIN']) ) {
+       if ( $wgCrossSiteAJAXdomains == '*' ) {
+               header( "Access-Control-Allow-Origin: {$_SERVER['HTTP_ORIGIN']}" );
+               header( 'Access-Control-Allow-Credentials: true' );
+       } elseif ( $wgCrossSiteAJAXdomainsRegex ) {
+               foreach ( $wgCrossSiteAJAXdomains as $regex ) {
+                       if ( preg_match( $regex, $_SERVER['HTTP_ORIGIN'] ) ) {
+                               header( "Access-Control-Allow-Origin: {$_SERVER['HTTP_ORIGIN']}" );
+                               header( 'Access-Control-Allow-Credentials: true' );
+                               break;
+                       }
+               }
+       } elseif ( in_array( $_SERVER['HTTP_ORIGIN'], $wgCrossSiteAJAXdomains ) ) {
+               header( "Access-Control-Allow-Origin: {$_SERVER['HTTP_ORIGIN']}" );
+               header( 'Access-Control-Allow-Credentials: true' );
+       }
 }
 
+// So extensions can check whether they're running in API mode
+define('MW_API', true);
+
+// Set a dummy $wgTitle, because $wgTitle == null breaks various things
+// In a perfect world this wouldn't be necessary
+$wgTitle = Title::newFromText('API');
+
 /* Construct an ApiMain with the arguments passed via the URL. What we get back
  * is some form of an ApiMain, possibly even one that produces an error message,
  * but we don't care here, as that is handled by the ctor.
@@ -76,7 +98,13 @@ $processor = new ApiMain($wgRequest, $wgEnableWriteAPI);
 // Process data & print results
 $processor->execute();
 
+// Execute any deferred updates
+wfDoUpdates();
+
 // Log what the user did, for book-keeping purposes.
 wfProfileOut('api.php');
 wfLogProfilingData();
 
+// Shut down the database
+wfGetLBFactory()->shutdown();
+
@@ -1,25 +1,27 @@
 <?php
 
-/*
-* API for MediaWiki 1.8+
-*
-* Copyright (C) 2006 Yuri Astrakhan <Firstname><Lastname>@gmail.com
-*
-* This program is free software; you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
-* (at your option) any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License along
-* with this program; if not, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-* http://www.gnu.org/copyleft/gpl.html
-*/
+/**
+ * API for MediaWiki 1.8+
+ *
+ * Copyright (C) 2006 Yuri Astrakhan <Firstname><Lastname>@gmail.com
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * http://www.gnu.org/copyleft/gpl.html
+ *
+ * @file
+ */
 
 /** 